@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2008- Samuli Jrvel
+ * Copyright (c) 2008- Samuli Järvelä
  *
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
@@ -20,7 +20,7 @@ function MollifyPublishedFoldersConfigurationView() {
 		$("#button-edit-folder").click(that.openEditFolder);
 		$("#button-refresh-folders").click(that.refresh);
 
-		$("#folders-list").jqGrid({        
+		$("#folders-list").jqGrid({
 			datatype: "local",
 			multiselect: false,
 			autowidth: true,
@@ -31,6 +31,7 @@ function MollifyPublishedFoldersConfigurationView() {
 		   		{name:'name',index:'name', width:200, sortable:true},
 				{name:'path',index:'path',width:150, sortable:true},
 		   	],
+		   	rowNum:9999,
 		   	sortname:'id',
 		   	sortorder:'asc',
 			onSelectRow: function(id){
@@ -42,16 +43,18 @@ function MollifyPublishedFoldersConfigurationView() {
 		$("#button-remove-folder-users").click(that.onRemoveFolderUsers);
 		$("#button-refresh-folder-users").click(that.refreshFolderUsers);
 
-		$("#folder-users-list").jqGrid({        
+		$("#folder-users-list").jqGrid({
 			datatype: "local",
 			multiselect: true,
 			autowidth: true,
 			height: '100%',
-		   	colNames:['ID', 'Name'],
+		   	colNames:['ID', 'Name', 'Type'],
 		   	colModel:[
 			   	{name:'id',index:'id', width:60, sortable:true, sorttype:"int"},
-		   		{name:'name',index:'name', width:200, sortable:true}
+		   		{name:'name',index:'name', width:200, sortable:true},
+		   		{name:'is_group',index:'is_group', width:50, sortable:true, formatter:that.groupFormatter}
 		   	],
+		   	rowNum:9999,
 		   	sortname:'id',
 		   	sortorder:'asc',
 			onSelectRow: function(id){
@@ -59,15 +62,17 @@ function MollifyPublishedFoldersConfigurationView() {
 			}
 		});
 		
-		$("#add-users-list").jqGrid({        
+		$("#add-users-list").jqGrid({
 			datatype: "local",
 			autowidth: true,
 			multiselect: true,
-		   	colNames:['ID', 'Name'],
+		   	colNames:['ID', 'Name', 'Type'],
 		   	colModel:[
 			   	{name:'id',index:'id', width:60, sortable:true, sorttype:"int"},
-		   		{name:'name',index:'name', width:200, sortable:true}
+		   		{name:'name',index:'name', width:200, sortable:true},
+		   		{name:'is_group',index:'is_group', width:50, sortable:true, formatter:that.groupFormatter}
 		   	],
+		   	rowNum:9999,
 		   	sortname:'id',
 		   	sortorder:'asc'
 		});
@@ -75,6 +80,11 @@ function MollifyPublishedFoldersConfigurationView() {
 		that.refresh();
 	}
 	
+	this.groupFormatter = function(name, options, u) {
+		if (u.is_group == "1") return "Group";
+		return "User";
+	}
+	
 	this.getFolder = function(id) {
 		return that.folders[id];
 	}
@@ -84,7 +94,7 @@ function MollifyPublishedFoldersConfigurationView() {
 	}
 	
 	this.getSelectedFolderUsers = function() {
-		return $("#folder-users-list").getGridParam("selarrrow");
+		return getValidSelections($("#folder-users-list").getGridParam("selarrrow"));
 	}
 	
 	this.refresh = function() {
@@ -106,16 +116,21 @@ function MollifyPublishedFoldersConfigurationView() {
 		
 		that.onFolderSelectionChanged();
 		
-		getUsers(that.refreshUsers, onServerError);
+		getUsersAndGroups(that.refreshUsersAndGroups, onServerError);
 	}
 	
-	this.refreshUsers = function(users) {
+	this.refreshUsersAndGroups = function(result) {
 		that.users = {};
+		that.groups = {};
 		
-		for (var i=0; i < users.length; i++) {
-			user = users[i];
+		for (var i=0; i < result.users.length; i++) {
+			user = result.users[i];
 			that.users[user.id] = user;
 		}
+		for (var i=0; i < result.groups.length; i++) {
+			group = result.groups[i];
+			that.groups[group.id] = group;
+		}
 	}
 	
 	this.refreshFolderUsers = function() {
@@ -201,11 +216,7 @@ function MollifyPublishedFoldersConfigurationView() {
 			});
 		}
 		
-		var buttons = {
-			Cancel: function() {
-				$(this).dialog('close');
-			}
-		}
+		var buttons = {}
 		
 		var action = function() {
 			$("#folder-dialog > .form-data").removeClass("invalid");
@@ -251,6 +262,10 @@ function MollifyPublishedFoldersConfigurationView() {
 			buttons["Edit"] = action;
 		else
 			buttons["Add"] = action;
+			
+		buttons["Cancel"] = function() {
+			$(this).dialog('close');
+		};
 
 		$("#folder-dialog").dialog('option', 'buttons', buttons);
 		$("#folder-dialog > .form-data").removeClass("invalid");
@@ -299,12 +314,12 @@ function MollifyPublishedFoldersConfigurationView() {
 		}
 		
 		var buttons = {
-			No: function() {
-				$(this).dialog('close');
-			},
 			Yes: function() {
 				var deleteFolderContents = $("#delete-folder-contents").attr('checked');
 				removeFolder(id, deleteFolderContents, onSuccess, onServerError);
+			},
+			No: function() {
+				$(this).dialog('close');
 			}
 		}
 
@@ -320,7 +335,7 @@ function MollifyPublishedFoldersConfigurationView() {
 		
 		var availableUsers = that.getAvailableFolderUsers();
 		if (availableUsers.length == 0) {
-			alert("No more users available");
+			alert("No more users or groups available");
 			return;
 		}
 		
@@ -335,11 +350,8 @@ function MollifyPublishedFoldersConfigurationView() {
 			that.addUserDialogInit = true;
 			
 			var buttons = {
-				Cancel: function() {
-					$(this).dialog('close');
-				},
 				Add: function() {
-					var sel = $("#add-users-list").getGridParam("selarrrow");
+					var sel = getValidSelections($("#add-users-list").getGridParam("selarrrow"));
 					if (sel.length == 0) return;
 	
 					var onSuccess = function() {
@@ -348,13 +360,16 @@ function MollifyPublishedFoldersConfigurationView() {
 					}
 					
 					addFolderUsers(that.getSelectedFolder(), sel, onSuccess, onServerError);
+				},
+				Cancel: function() {
+					$(this).dialog('close');
 				}
 			}
 					
 			$("#add-folder-users-dialog").dialog({
 				bgiframe: true,
 				height: 'auto',
-				width: 330,
+				width: 380,
 				modal: true,
 				resizable: true,
 				autoOpen: false,
@@ -372,6 +387,10 @@ function MollifyPublishedFoldersConfigurationView() {
 			if (!that.folderUsers[id])
 				result.push(that.users[id]);
 		}
+		for (id in that.groups) {
+			if (!that.folderUsers[id])
+				result.push(that.groups[id]);
+		}
 		return result;
 	}
 
