@@ -19,24 +19,29 @@
 		<title>Mollify Administration</title>
 		<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
 		
-		<link rel="stylesheet" href="../resources/jquery-ui-1.7.2.custom.css">
+		<link rel="stylesheet" href="../resources/jquery-ui-1.8.5.custom.css">
 		<link rel="stylesheet" href="../resources/ui.jqgrid.css">
 		<link rel="stylesheet" href="resources/style.css">
 		
-		<script type="text/javascript" src="../resources/jquery-1.3.2.min.js"></script>
+		<script type="text/javascript" src="../resources/jquery-1.4.2.min.js"></script>
 		<script type="text/javascript" src="../resources/md5.js"></script>
+		<script type="text/javascript" src="../resources/base64.js"></script>
 		<script type="text/javascript" src="../resources/json.js"></script>
 		<script type="text/javascript" src="../resources/template.js"></script>
-		<script type="text/javascript" src="../resources/jquery-ui-1.7.2.custom.min.js"></script>
+		<script type="text/javascript" src="../resources/jquery-ui-1.8.5.custom.min.js"></script>
 		<script type="text/javascript" src="../resources/jquery.jqGrid.min.js"></script>
+		<script type="text/javascript" src="../resources/jquery.tools.min.js"></script>
 		<script type="text/javascript" src="resources/service.js"></script>
-		<?php if (file_exists("settings.js")) { ?><script type="text/javascript" src="settings.js"></script><?php } ?>
 		<script type="text/javascript" src="resources/main.js"></script>
+		<?php if (file_exists("settings.js")) { ?><script type="text/javascript" src="settings.js"></script><?php } ?>		
 	</head>	
 	
 	<body id="page-admin">
 		<header>
 			<h1>Administration</h1>
+			<div id="mollify-version"></div>
+			<div id="mollify-update-info" class="tooltip" style="display:none"></div>
+			<div id="admin-logout">Logout</div>
 		</header>
 
 		<div id="content" class="content" style="display:none">
