@@ -8,11 +8,30 @@
 	this entire header must remain intact.
 */
 
+(function(){
+window.mollify = new function() {
+	this.time = new Date().getTime();
+	
+	this.admin = new function() {
+		var t = this;
+		
+		this.settings = {
+			"date-format" : "mm/dd/yy",
+			"datetime-format" : "mm/dd/yy hh.MM t"
+		}
+		
+		this.init = function(s) {
+			if (!s) return;
+			for (var k in s) t.settings[k] = s[k];
+		}
+	}
+}
+})();
+
 var session = null;
-var loadedScripts = new Array();
+var loadedScripts = [];
 var controller = null;
 var controllers = {};
-var settings = createSettings();
 var plugins = {};
 
 var views = [
@@ -28,9 +47,17 @@ $(document).ready(function() {
 	postRequestCallback = function() { $("#request-indicator").removeClass("active"); }
 	$.datepicker.setDefaults( { dateFormat: getDateFormat() } );
 	
-	getSessionInfo(onSession, onServerError);				
+	$("#admin-logout").click(function() {
+		doLogout(onLogout, onServerError);
+	});
+	
+	getSessionInfo(onSession, onServerError);
 });
 
+function onLogout() {
+	window.location = window.location;
+}
+
 function buildMenu() {
 	var html = '<ul>';
 	
@@ -45,8 +72,8 @@ function buildMenu() {
 	}
 	
 	// custom views
-	if (settings.views) {
-		var customViews = [{header:"Custom", id:'menu-header-custom', views: settings.views}];
+	if (getSettings().views) {
+		var customViews = [{header:"Custom", id:'menu-header-custom', views: getSettings().views}];
 		html += createMenuItems(customViews, 'custom/');
 	}
 	
@@ -60,6 +87,8 @@ function buildMenu() {
 	});
 	
 	$("#content").show();
+	
+	showVersion();
 }
 
 function createMenuItems(views, pathPrefix) {
@@ -113,6 +142,20 @@ function onSession(session) {
 	else loadPlugin(pluginsToInit, 0);
 }
 
+function showVersion() {
+	$("#mollify-version").html("Version "+session.version);
+	if (getSettings()["disable-version-check"] === true) return;
+	
+	$.getJSON("http://www.mollify.org/latest.php?jsoncallback=?", function(result) {
+		if (!result || !result.version) return;
+		if (result.version != session.version) {
+			$("#mollify-update-info").html("<h1>Update available!</h1><p><span class='title'>Latest version:</span>&nbsp;"+result.version+"<br/><span class='title'>Release date:</span>&nbsp;"+result.date+"</p><p><a id='update-download-link' href='http://www.mollify.org/download.php' class='update-link' target='_new'>Download</a>&nbsp;<a id='update-changelog-link' class='update-link' href='http://code.google.com/p/mollify/wiki/ChangeLog' target='_new'>Change log</a></p>");
+			$("#mollify-version").tooltip({ effect: "slide", position: "bottom"});
+			$("#mollify-version").addClass("update");
+		}
+	});
+}
+
 function loadPlugin(list, i) {
 	var id = list[i];
 	var cb = function() {
@@ -126,7 +169,7 @@ function loadPlugin(list, i) {
 	};
 	loadScript("../plugin/"+id+"/admin/init.js", cb);
 }
-		
+
 function onSelectMenu(id) {
 	if (!controllers[id]) {
 		onError("Configuration view not defined: "+id);
@@ -141,7 +184,7 @@ function loadScript(script, cb) {
 		if (cb) cb();
 		return;
 	}
-	$.getScript(script, function() {
+	$.getScript(script+"?_="+mollify.time, function() {
 		loadedScripts.push(script);
 		if (cb) cb();
 	});
@@ -168,7 +211,7 @@ function getSession() {
 }
 
 function getSettings() {
-	return settings;
+	return mollify.admin.settings;
 }
 
 function notify(msg) {
@@ -210,11 +253,11 @@ function enableButton(id, enabled) {
 }
 
 function getDateFormat() {
-	return settings.dateFormat;
+	return getSettings()["date-format"];
 }
 
 function getDateTimeFormat() {
-	return settings.dateTimeFormat;
+	return getSettings()["datetime-format"];
 }
 
 function formatDate(d) {
@@ -222,6 +265,7 @@ function formatDate(d) {
 }
 
 function formatDateTime(time) {
+	if (!time) return "";
 	return time.format(getDateTimeFormat());
 }
 
@@ -245,18 +289,9 @@ function parseInternalTime(time) {
 }
 
 function formatInternalTime(time) {
+	if (!time) return null;
 	return time.format('yymmddHHMMss', time);
 }
-	
-function createSettings() {
-	var settings = {};
-	
-	if (window.customSettings) settings = window.customSettings;
-	if (!settings.dateFormat) settings.dateFormat = "mm/dd/yy";
-	if (!settings.dateTimeFormat) settings.dateTimeFormat = "mm/dd/yy hh.MM t";
-	
-	return settings;
-}
 
 function initWidgets() {
 	$('button').each(function() {
@@ -304,6 +339,14 @@ function getRandomNumber() {
 	return (parseInt(Math.random() * 1000) % 94) + 33;
 }
 
+function inArray(o, a) {
+	if (!a) return false;
+	for (var i=0; i < a.length; i++) {
+		if (a[i] == o) return true;
+	}
+	return false;
+}
+
 Date.prototype.format = function(format) {
 	var date = this;
 	if (!format) format="mm/dd/yy";               
@@ -371,13 +414,82 @@ String.prototype.padR = function(width, pad) {
 	return (this + String.repeat(pad,length)).substr(0,width);
 }
 
+function getValidSelections(list) {
+	var result = [];
+	for (var i=0; i < list.length; i++) {
+		var v = list[i];
+		if (!v || v.length == 0) continue;
+		result.push(v);
+	}
+	return result;
+}
+
 // jqGrid formatters
 
 function timeFormatter(time, options, obj) {
 	return formatDateTime(time);
 }
+
+function dateFormatter(time, options, obj) {
+	return formatDate(time);
+}
 	
 function notNullFormatter(o, options, obj) {
 	if (o == null) return '';
 	return o;
-}
\ No newline at end of file
+}
+
+/*
+  This license is based on the new BSD template found here 
+  (http://www.opensource.org/licenses/bsd-license.php)
+  
+  -----------------------------------------------------------------
+  CodeIncubator (http://codeincubator.com)
+  Copyright (c) 2009 
+  by Steven Harman (http://stevenharman.net)
+  
+  All rights reserved.
+  
+  Redistribution and use in source and binary forms, with or without modification, 
+  are permitted provided that the following conditions are met:
+  
+      * Redistributions of source code must retain the above copyright notice, 
+                this list of conditions and the following disclaimer.
+      * Redistributions in binary form must reproduce the above copyright notice, 
+                this list of conditions and the following disclaimer in the documentation 
+                and/or other materials provided with the distribution.
+      * Neither the name of the CodeIncubator nor the names of its contributors 
+                may be used to endorse or promote products derived from this software 
+                without specific prior written permission.
+  
+  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
+  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
+  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
+  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
+  INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
+  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, 
+  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY 
+  OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE 
+  OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED 
+  OF THE POSSIBILITY OF SUCH DAMAGE.
+*/
+
+(function($) {
+	jQuery.jgrid.fluid = {
+    	fluidGrid: function(options) {
+			var grid = $(this);
+			
+			var settings = $.extend({
+				example: grid.closest('.ui-jqgrid').parent(),
+				offset: 0
+            }, options || {});
+			
+			var w = $(settings.example).innerWidth() + settings.offset;
+			if (w <= 0) return;
+			
+			grid.setGridWidth(w);
+    	}
+	}}
+)(jQuery);
+	
+jQuery.fn.extend({ fluidGrid : jQuery.jgrid.fluid.fluidGrid });
\ No newline at end of file
