@@ -18,24 +18,25 @@
 			"file_upload_progress" => FALSE,
 			"zip_download" => FALSE,
 			"change_password" => FALSE,
-			"description_update" => FALSE,
-			"permission_update" => FALSE,
+			"descriptions" => FALSE,
 			"administration" => FALSE,
 			"user_groups" => FALSE,
-			"public_links" => FALSE,
-			"mail_notification" => FALSE
+			"mail_notification" => FALSE,
+			"retrieve_url" => FALSE,
+			"folder_protection" => FALSE,
+			"guest_mode" => FALSE
 		);
 		
 		private $defaultValues = array();
 		
-		private static $featuresControlledByConfigurationProvider = array("change_password", "description_update", "permission_update", "administration", "user_groups");
+		private static $featuresControlledByConfiguration = array("change_password", "descriptions", "administration", "user_groups");
 		
 		function __construct($configuration, $settings) {
 			$configurationFeatures = $configuration->getSupportedFeatures();
 			
 			foreach ($this->features as $f=>$k) {
 				$enabled = FALSE;
-				$configControlled = in_array($f, self::$featuresControlledByConfigurationProvider);
+				$configControlled = in_array($f, self::$featuresControlledByConfiguration);
 				
 				if ($configControlled) {
 					$configSupported = in_array($f, $configurationFeatures);
@@ -78,4 +79,4 @@
 			return "Features";
 		}
 	}
-?>
\ No newline at end of file
+?>
