@@ -15,7 +15,9 @@
 	require_once("filesystem/FilesystemController.class.php");
 	require_once("plugin/PluginController.class.php");
 	require_once("services/ServicesBase.class.php");
-	require_once("MailNotification.class.php");
+	require_once("event/EventHandler.class.php");
+	require_once("Formatter.class.php");
+	require_once("Cookie.class.php");
 	
 	class ServiceEnvironment {
 		const ENTRY_SCRIPT = 'r.php';
@@ -25,34 +27,49 @@
 		private $serviceControllerPaths = array();
 		
 		private $session;
-		private $authentication; 
+		private $authentication;
 		private $responseHandler;
-		private $configurationProvider;
+		private $configuration;
 		private $settings;
 		private $eventHandler;
 		private $filesystem;
 		private $request;
-		private $notification;
+		private $notificator = NULL;
+		private $urlRetriever = NULL;
 		
-		public function __construct($session, $responseHandler, $configurationProvider, $settings) {
+		public function __construct($session, $responseHandler, $configuration, $settings) {
 			$this->session = $session;
 			$this->responseHandler = $responseHandler;
-			$this->configurationProvider = $configurationProvider;
+			$this->configuration = $configuration;
 			$this->settings = $settings;
-			$this->features = new Features($configurationProvider, $settings);
+			$this->cookies = new Cookie($settings);
+			$this->features = new Features($configuration, $settings);
 			$this->authentication = new Authentication($this);
 			$this->eventHandler = new EventHandler($this);
 			$this->filesystem = new FilesystemController($this);
 			$this->plugins = new PluginController($this);
-			$this->notification = new MailNotification($this);
 			
 			if ($settings->hasSetting('timezone')) date_default_timezone_set($settings->setting('timezone'));
 		}
 		
+		private function createMailNotificator() {
+			require_once($this->settings->setting("mail_notificator_class", TRUE));
+			return new MailNotificator($this);
+		}
+		
+		private function createUrlRetriever() {
+			require_once($this->settings->setting("url_retriever_class", TRUE));
+			return new UrlRetriever($this);
+		}
+		
 		public function session() {
 			return $this->session;
 		}
 
+		public function cookies() {
+			return $this->cookies;
+		}
+
 		public function response() {
 			return $this->responseHandler;
 		}
@@ -62,7 +79,7 @@
 		}
 		
 		public function configuration() {
-			return $this->configurationProvider;
+			return $this->configuration;
 		}
 
 		public function features() {
@@ -89,17 +106,26 @@
 			return $this->request;
 		}
 
-		public function notification() {
-			return $this->notification;
+		public function notificator() {
+			if ($this->notificator == NULL)
+				$this->notificator = $this->createMailNotificator();
+			return $this->notificator;
+		}
+		
+		public function urlRetriever() {
+			if ($this->urlRetriever == NULL)
+				$this->urlRetriever = $this->createUrlRetriever();
+			return $this->urlRetriever;
+		}
+		
+		public function formatter() {
+			return new Formatter($this->settings);
 		}
 										
 		public function initialize($request = NULL) {
-			$sessionId = NULL;
-			if ($request != NULL and $request->hasParam("session")) $sessionId = $request->param("session");
-			$this->request = $request;
-			
-			$this->session->initialize($this, $sessionId);
-			$this->configurationProvider->initialize($this);
+			$this->request = $request;			
+			$this->session->initialize($this, $request);
+			$this->configuration->initialize($this);
 			$this->filesystem->initialize();
 			$this->authentication->initialize();
 			$this->plugins->initialize($this);
@@ -114,6 +140,8 @@
 		
 		public function getService($request) {
 			$path = $request->path();
+			if (count($path) === 0) throw new ServiceException("Empty request");
+			
 			$id = $path[0];
 			if (!array_key_exists($id, $this->services)) throw new ServiceException("Unknown service '".$id."'");
 			
@@ -139,8 +167,12 @@
 			return $url."/";
 		}
 		
-		public function getPluginUrl($pluginId, $path = NULL) {
-			return $this->getResourceUrl("plugin/".$pluginId."/".($path != NULL ? $path."/" : ""));
+		public function getPluginBaseUrl() {
+			return $this->getResourceUrl("plugin/");
+		}
+		
+		public function getPluginUrl($pluginId, $path = NULL, $file = FALSE) {
+			return $this->getPluginBaseUrl().$pluginId."/".($path != NULL ? $path.($file ? "" : "/") : "");
 		}
 		
 		public function getResourceUrl($path) {
@@ -153,6 +185,8 @@
 		
 		private function getHost() {
 			if (!$this->settings->hasSetting("host_public_address")) {
+				if (!isset($_SERVER['HTTP_REFERER'])) throw new ServiceException("Cannot resolve host");
+				
 				$protocol = substr($_SERVER['HTTP_REFERER'], 0, strpos($_SERVER['HTTP_REFERER'], ":"));
 				$start = strlen($protocol) + 3;
 				$end = strpos($_SERVER['HTTP_REFERER'], "/", $start);
@@ -170,17 +204,29 @@
 			$root = substr($_SERVER['SCRIPT_NAME'], 0, strlen($_SERVER['SCRIPT_NAME']) - strlen(self::ENTRY_SCRIPT));
 			return $this->getHost().$root;
 		}
+
+		public function getScriptRootPath() {			
+			return substr($_SERVER['SCRIPT_FILENAME'], 0, strlen($_SERVER['SCRIPT_FILENAME']) - strlen(self::ENTRY_SCRIPT));
+		}
+		
+		public function convertCharset($s, $encode = TRUE) {
+			$cs = $this->settings->setting("convert_filenames", TRUE);
+			if (!$cs) return $s;
+			if ($cs === TRUE) $cs = NULL;
+			return Util::convertCharset($s, $cs, $encode);
+		}
 		
 		public function log() {
 			if (!Logging::isDebug()) return;
 			Logging::logSystem();
 			
 			$this->settings->log();
-			$this->configurationProvider->log();
+			$this->configuration->log();
 			$this->features->log();
 			$this->filesystem->log();
 			$this->session->log();
 			$this->authentication->log();
+			if ($this->request) $this->request->log();
 		}
 		
 		public function __toString() {
@@ -204,4 +250,4 @@
 			return $this->getMessage();
 		}
 	}
-?>
\ No newline at end of file
+?>
