@@ -14,27 +14,41 @@
 		private $settings = array();
 		
 		private static $VALUES = array(
+			"email_login" => FALSE,
 			"host_public_address" => NULL,
 			"session_name" => NULL,
+			"session_time" => 7200,
 			"timezone" => NULL,
 			"enable_limited_http_methods" => FALSE,
 			"enable_file_upload" => TRUE,
 			"enable_folder_actions" => TRUE,
 			"enable_file_upload_progress" => FALSE,
 			"enable_zip_download" => FALSE,
+			"zipper" => "ZipArchive",
 			"enable_change_password" => TRUE,
-			"enable_description_update" => FALSE,
-			"enable_permission_update" => FALSE,
+			"enable_descriptions" => FALSE,
+			"enable_mail_notification" => FALSE,
+			"enable_retrieve_url" => FALSE,
 			"allowed_file_upload_types" => array(),
 			"firebug_logging" => FALSE,
-			"zip_options" => array(),
-			"permission_file" => "mollify.uac",
-			"description_file" => "mollify.dsc",
-			"enable_public_links" => FALSE,
-			"enable_mail_notification" => FALSE,
-			"mail_notification_from" => NULL,
+			"mail_notification_from" => "Admin",
 			"new_folder_permission_mask" => 0755,
-			"debug" => FALSE
+			"convert_filenames" => FALSE,
+			"support_output_buffer" => FALSE,
+			"mail_notificator_class" => "mail/MailNotificator.class.php",
+			"url_retriever_class" => "UrlRetriever.class.php",
+			"datetime_format" => "d.m.Y H:i:s",
+			"mime_types" => array(),
+			"authentication_methods" => array("pw"),
+			"ldap_server" => NULL,
+			"ldap_conn_string" => NULL,
+			"upload_temp_dir" => NULL,
+			"enable_thumbnails" => TRUE,
+			"enable_folder_protection" => FALSE,
+			"enable_guest_mode" => FALSE,
+			"guest_user_id" => FALSE,
+			"debug" => FALSE,
+			"debug_log" => NULL
 		);
 		
 		function __construct($settings) {
@@ -59,6 +73,10 @@
 			return array_key_exists($setting, $this->settings);
 		}
 		
+		public function getAllSettings() {
+			return $this->settings;
+		}
+		
 		function log() {
 			Logging::logDebug("SETTINGS: ".Util::array2str($this->settings));
 		}
@@ -67,4 +85,4 @@
 			return "Settings";
 		}
 	}
-?>
\ No newline at end of file
+?>
