@@ -33,12 +33,21 @@
 		}
 		
 		public function onEvent($e) {
-			$e->setUser($this->env->authentication()->isAuthenticated() ? $this->env->authentication()->getUserInfo() : NULL);
+			if ($this->env->authentication()->isAuthenticated()) {
+				$e->setUser(array(
+					'user_id' => $this->env->session()->userId(),
+					'username' => $this->env->session()->username(),
+				));
+			} else {
+				$e->setUser(NULL);
+			}
+
+			$e->setIp($this->env->request()->ip());
 			
 			if (Logging::isDebug()) Logging::logDebug("EVENT HANDLER: onEvent: '".$e->type()."'");
 			
 			foreach($this->listeners as $type => $listeners) {
-				if ($type == '*' or strpos($e->typeId(), $type) == 0) {
+				if (strcasecmp($type, '*') == 0 or strpos($e->typeId(), $type) === 0) {
 					foreach($listeners as $listener)
 						$listener->onEvent($e);
 				}
@@ -57,6 +66,7 @@
 	abstract class Event {
 		private $time;
 		protected $user = NULL;
+		protected $ip = NULL;
 		private $type;
 		private $subType;
 		
@@ -73,7 +83,11 @@
 		public function user() {
 			return $this->user;
 		}
-				
+
+		public function ip() {
+			return $this->ip;
+		}
+						
 		public function type() {
 			return $this->type;
 		}
@@ -94,8 +108,27 @@
 			$this->user = $user;
 		}
 		
+		public function setIp($ip) {
+			$this->ip = $ip;
+		}
+		
+		public function values($formatter) {
+			$values = array(
+				"ip" => $this->ip(),
+				"event_type" => $this->typeId(),
+				"event_main_type" => $this->type,
+				"event_sub_type" => $this->subType,
+				"event_time" => $formatter->formatDateTime($this->time)
+			);
+			if ($this->user != NULL) {
+				$values["user_id"] = $this->user["user_id"];
+				$values["username"] = $this->user["username"];
+			}
+			return $values;
+		}
+		
 		public function __toString() {
-			return "Event ".$this->type;
+			return "Event ".$this->typeId();
 		}
 	}
 ?>
\ No newline at end of file
