@@ -488,13 +488,39 @@
 			if (!$range)
 				$this->env->events()->onEvent(FileEvent::download($file));
 
-			$this->env->response()->download($name, $file->extension(), $mobile, $file->read($range), $size, $range);
+			$this->env->response()->download($name, $file->extension(), Util::isMobile(), $file->read($range), $size, $range);
 		}
 
-		public function view($file) {
-			Logging::logDebug('view ['.$file->id().']');
+		public function view($file, $range = NULL) {
+			if (!$range)
+				Logging::logDebug('view ['.$file->id().']');
 			$this->assertRights($file, Authentication::RIGHTS_READ, "view");
-			$this->env->events()->onEvent(FileEvent::view($file));
+			
+			$size = $file->size();
+			if ($range != NULL) {
+				list($unit, $range) = explode('=', $range, 2);
+				
+				if ($unit == 'bytes') {
+					$pos = strpos(",", $range);
+					if ($pos != false) {
+						if ($pos === 0) $range = NULL;
+						else if ($pos >= 0) $range = substr($range, 0, $pos);
+					}
+				} else {
+					$range = NULL;
+				}
+			}
+			
+			if ($range != NULL) {
+				list($start, $end) = explode('-', $range, 2);
+
+				$end = (empty($end)) ? ($size - 1) : min(abs(intval($end)),($size - 1));
+				$start = (empty($start) || $end < abs(intval($start))) ? 0 : max(abs(intval($start)),0);
+				$range = array($start, $end, $size);
+				Logging::logDebug("View range ".$start."-".$end);
+			}
+			if (!$range)
+				$this->env->events()->onEvent(FileEvent::view($file));
 			$this->env->response()->send($file->name(), $file->extension(), $file->read(), $file->size());
 		}
 		
@@ -566,11 +592,12 @@
 			$this->env->events()->onEvent(FileEvent::upload($targetItem));
 		}
 		
-		public function downloadAsZip($items, $mobile) {
+		public function downloadAsZip($items, $mobile = FALSE) {
 			$zip = $this->createZip($items);
 			$name = "items.zip";
 			if (!is_array($items)) $name = $items->name().".zip";
-			$this->env->response()->download($name, "zip", $mobile, $zip->stream());	
+			$this->env->response()->download($name, "zip", Util::isMobile(), $zip->stream());
+			unlink($zip->filename());
 		}
 		
 		public function storeZip($items) {
@@ -591,17 +618,18 @@
 
 			$handle = @fopen($filename, "rb");
 			if (!$handle)
-				throw new ServiceException("REQUEST_FAILED", "Could not open zip for reading: ".$this->name);
-			$this->env->response()->download("items.zip", "zip", $mobile, $handle);
+				throw new ServiceException("REQUEST_FAILED", "Could not open zip for reading: ".$filename);
+			$this->env->response()->download("items.zip", "zip", Util::isMobile(), $handle);
+			unlink($filename);
 		}
 		
-		private function createZip($items) {
+		public function createZip($items, $name = FALSE) {
 			$this->env->features()->assertFeature("zip_download");
 			
 			if (is_array($items)) {
 				$this->assertRights($items, Authentication::RIGHTS_READ, "download as zip");
 				
-				$zip = $this->zipper();
+				$zip = $this->zipper($name);
 				foreach($items as $item) {
 					$item->addToZip($zip);
 					$this->env->events()->onEvent(FileEvent::download($item));
@@ -661,19 +689,19 @@
 			return $result;
 		}
 		
-		public function zipper() {
+		public function zipper($name = FALSE) {
 			require_once('zip/MollifyZip.class.php');
 			$zipper = $this->setting("zipper", TRUE);
 			
 			if (strcasecmp($zipper, "ziparchive") === 0) {
 				require_once('zip/MollifyZipArchive.class.php');
-				return new MollifyZipArchive($this->env);
+				return new MollifyZipArchive($this->env, $name);
 			} else if (strcasecmp($zipper, "native") === 0) {
 				require_once('zip/MollifyZipNative.class.php');
-				return new MollifyZipNative($this->env);
+				return new MollifyZipNative($this->env, $name);
 			} else if (strcasecmp($zipper, "raw") === 0) {
 				require_once('zip/MollifyZipRaw.class.php');
-				return new MollifyZipRaw($this->env);
+				return new MollifyZipRaw($this->env, $name);
 			}
 			
 			throw new ServiceException("INVALID_CONFIGURATION", "Unsupported zipper configured: ".$zipper);
