@@ -24,21 +24,17 @@
 		}
 		
 		abstract function isFile();
-		
+				
 		public function id() {
 			return $this->id;
 		}
 		
-		public function publicId() {
-			return base64_encode($this->id());
-		}
-
 		public function rootId() {
 			return $this->rootId;
 		}
-
-		public function publicRootId() {
-			return base64_encode($this->rootId());
+		
+		public function exists() {
+			return $this->filesystem->itemExists($this);
 		}
 		
 		public function internalPath() {
@@ -52,10 +48,18 @@
 		public function parent() {
 			return $this->filesystem->parent($this);
 		}
+
+		public function hierarchy() {
+			return $this->filesystem->hierarchy($this);
+		}
 		
 		public function name() {
 			return $this->name;
 		}
+
+		public function location() {
+			return $this->filesystem->itemLocation($this->path);
+		}
 		
 		public function path() {
 			return $this->path;
@@ -97,8 +101,20 @@
 			return $this->filesystem->addToZip($this, $zip);
 		}
 		
+		public function isRoot() {
+			return FALSE;
+		}
+		
 		public function data() {
-			return array("id" => $this->publicId(), "root_id" => $this->publicRootId(), "parent_id" => $this->parent()->publicId(), "name" => $this->name, "path" => $this->path);
+			$p = $this->parent();
+			return array(
+				"id" => $this->id,
+				"root_id" => $this->rootId(),
+				"parent_id" => ($p != NULL) ? $p->id() : "",
+				"name" => $this->name,
+				"path" => $this->path,
+				"is_file" => $this->isFile()
+			);
 		}
 				
 		public function __toString() {
@@ -121,8 +137,8 @@
 			return $this->filesystem->read($this);
 		}
 		
-		public function write() {
-			return $this->filesystem->write($this);
+		public function write($s) {
+			return $this->filesystem->write($this, $s);
 		}
 
 		public function put($content) {
@@ -144,12 +160,12 @@
 			return $this->filesystem->items($this);
 		}
 
-		public function fileWithName($name, $nonExisting = FALSE) {
-			return $this->filesystem->fileWithName($this, $name, $nonExisting);
+		public function fileWithName($name) {
+			return $this->filesystem->fileWithName($this, $name);
 		}
 
-		public function folderWithName($name, $nonExisting = FALSE) {
-			return $this->filesystem->folderWithName($this, $name, $nonExisting);
+		public function folderWithName($name) {
+			return $this->filesystem->folderWithName($this, $name);
 		}
 		
 		public function isRoot() {
