@@ -1,7 +1,7 @@
 <?php
 
 	/**
-	 * Copyright (c) 2008- Samuli Jrvel
+	 * Copyright (c) 2008- Samuli Järvelä
 	 *
 	 * All rights reserved. This program and the accompanying materials
 	 * are made available under the terms of the Eclipse Public License v1.0
@@ -15,9 +15,14 @@
 		
 		function __construct($id, $def, $filesystemInfo) {
 			parent::__construct($id, $def['name'] != NULL ? $def['name'] : $def['default_name'], $filesystemInfo);
+			if ($def == NULL or !isset($def["path"])) throw new ServiceException("INVALID_CONFIGURATION", "Invalid filesystem definition");
 			$this->rootPath = self::folderPath($def["path"]);
 		}
 		
+		public function isDirectDownload() {
+			return TRUE;
+		}
+		
 		public function assert() {
 			if (!$this->exists())
 				throw new NonExistingFolderException("INVALID_CONFIGURATION", "Invalid folder definition, path does not exist [".$this->id()."]");
@@ -28,47 +33,32 @@
 		}
 		
 		public function create() {
-			return mkdir($this->rootPath, 0755);
+			if (!mkdir($this->rootPath, 0755)) return FALSE;
+			if ($this->filesystemInfo->env()->features()->isFeatureEnabled("folder_protection")) {
+				copy($this->filesystemInfo->env()->getScriptRootPath()."/include/apache/htaccess", $this->rootPath.'.htaccess');
+			}
+			return TRUE;
 		}
 		
 		public function type() {
 			return MollifyFilesystem::TYPE_LOCAL;
 		}
-		
-		public function createItem($id, $path, $nonexisting = FALSE) {
-			if (strlen($path) > 0 and strpos("..", $path) != FALSE)
-				throw new ServiceException("INVALID_REQUEST", "Illegal path: ".$path);
+
+		public function createItemWithInternalPath($id, $path) {
+			if (strpos($path, $this->rootPath) === FALSE)
+				throw new ServiceException("INVALID_REQUEST", "Illegal filesystem (".$this->rootPath.") for path: ".$path);
+			return $this->createItem($id, $this->publicPath($path));
+		}
+				
+		public function createItem($id, $path) {
+			self::assertPath($path);
 			
 			$fullPath = self::joinPath($this->rootPath, $path);
 			$isFile = (strcasecmp(substr($fullPath, -1), DIRECTORY_SEPARATOR) != 0);
 			
-			if ($isFile) {
-				if (!$nonexisting and !$this->pathExists($fullPath))
-					throw new ServiceException("FILE_DOES_NOT_EXIST", 'id:'.$id.' path:'.$fullPath);
-
-				if ($nonexisting and $this->pathExists($fullPath))
-					throw new ServiceException("FILE_ALREADY_EXISTS", 'id:'.$id);
-				
-				if (!$nonexisting and !is_file($fullPath))
-					throw new ServiceException("NOT_A_FILE", 'id:'.$id);
-			} else {
-				if (!$nonexisting and !$this->pathExists($fullPath))
-					throw new ServiceException("DIR_DOES_NOT_EXIST", 'id:'.$id);
-
-				if ($nonexisting and $this->pathExists($fullPath))
-					throw new ServiceException("DIR_ALREADY_EXISTS", 'id:'.$id);
-
-				if (!$nonexisting and !is_dir($fullPath))
-					throw new ServiceException("NOT_A_DIR", 'id:'.$id);
-			}
-			
 			if ($isFile) return new File($id, $this->rootId(), $path, self::basename($fullPath), $this);
 			return new Folder($id, $this->rootId(), $path, self::basename($fullPath), $this);
 		}
-		
-		public function pathExists($path) {
-			return file_exists($path);
-		}
 
 		private function publicPath($path) {
 			return substr($path, strlen($this->rootPath));
@@ -79,13 +69,17 @@
 		}
 		
 		public function localPath($item) {
-			return self::joinPath($this->rootPath, $item->path());
+			return $this->filesystemInfo->env()->convertCharset(self::joinPath($this->rootPath, $item->path()), FALSE);
+		}
+		
+		public function itemExists($item) {
+			return file_exists($this->internalPath($item));
 		}
 		
 		public function details($item) {
-			$datetimeFormat = $this->filesystemInfo->datetimeFormat();
+			$datetimeFormat = $this->internalTimestampFormat();
 			
-			$details = array("id" => $item->publicId());
+			$details = array("id" => $item->id());
 			if ($item->isFile()) {
 				$path = $this->localPath($item);
 				$details["last_changed"] = date($datetimeFormat, filectime($path));
@@ -109,26 +103,53 @@
 			
 			$items = scandir($parentPath);
 			if (!$items) throw new ServiceException("INVALID_PATH", $parent->id());
+			
 			$ignored = $this->ignoredItems($this->publicPath($parentPath));
 				
 			$result = array();
 			foreach($items as $i => $name) {
 				if (substr($name, 0, 1) == '.') continue;
 				if (in_array(strtolower($name), $ignored)) continue;
-				$path = self::joinPath($parentPath, $name);
 				
-				if (!is_dir($path)) {	
+				$nativePath = self::joinPath($parentPath, $name);
+				$itemName = $this->filesystemInfo->env()->convertCharset($name);
+				$path = $this->filesystemInfo->env()->convertCharset($nativePath);
+				
+				if (!is_dir($nativePath)) {	
 					$p = $this->publicPath($path);
-					$result[] = new File($this->itemId($p), $this->rootId(), $p, $name, $this);
+					$result[] = new File($this->itemId($p), $this->rootId(), $p, $itemName, $this);
 				} else {
 					$p = $this->publicPath(self::folderPath($path));
-					$result[] = new Folder($this->itemId($p), $this->rootId(), $p, $name, $this);
+					$result[] = new Folder($this->itemId($p), $this->rootId(), $p, $itemName, $this);
 				}
 			}
 			
 			return $result;
 		}
 		
+		public function hierarchy($item) {
+			$p = $item->parent();
+			$result = array();
+			if ($p != NULL) {
+				$path = $this->localPath($p);
+
+				$root = $item->root();
+				$rootPath = $root->internalPath();
+				
+				$parts = preg_split("/\//", substr($path, strlen($rootPath)), -1, PREG_SPLIT_NO_EMPTY);
+				$current = $rootPath;
+				$result[] = $root;
+				
+				foreach($parts as $p) {
+					$public = $this->publicPath(self::folderPath($current));
+					$result[] = new Folder($this->itemId($public), $this->rootId(), $public, $this->filesystemInfo->env()->convertCharset($p), $this);				
+					$current .= $p.DIRECTORY_SEPARATOR;
+				}
+				if (!$item->isFile()) $result[] = $item;
+			}
+			return $result;
+		}
+		
 		private function allFilesRecursively($path) {
 			$files = scandir($path);
 			if (!$files) throw new ServiceException("INVALID_PATH", $this->path);
@@ -155,36 +176,39 @@
 			if ($item->path() === '') return NULL;
 			
 			$path = $this->localPath($item);
-			return $this->itemWithPath($this->publicPath(self::folderPath(dirname($path))));
+			return $this->itemWithPath($this->publicPath(self::folderPath($this->filesystemInfo->env()->convertCharset(dirname($path)))));
 		}
 
 		public function rename($item, $name) {
+			self::assertFilename($name);
+			
 			$old = $this->localPath($item);
-			$new = self::joinPath(dirname($old),$name);
+			$new = self::joinPath(dirname($old), $this->filesystemInfo->env()->convertCharset($name, FALSE));
+			
 			if (!$item->isFile()) $new = self::folderPath($new);
 
 			if (file_exists($new))
-				throw new ServiceException("FILE_ALREADY_EXISTS", "Failed to rename [".$item->id()."], target already exists ".self::basename($new));
+				throw new ServiceException("FILE_ALREADY_EXISTS", "Failed to rename [".$item->id()."], target already exists (".$new.")");
 
 			if (!rename($old, $new)) throw new ServiceException("REQUEST_FAILED", "Failed to rename [".$item->id()."]");
 			
-			return $this->itemWithPath($this->publicPath($new));
+			return $this->createItem($item->id(), $this->publicPath($this->filesystemInfo->env()->convertCharset($new)));
 		}
 
 		public function copy($item, $to) {			
-			$target = $this->localPath($to);
+			$target = $to->internalPath();
 
-			if (file_exists($target)) throw new ServiceException("FILE_ALREADY_EXISTS", "Failed to copy [".$item->id()."] to [".$to->id()."], target already exists");
+			if (file_exists($target)) throw new ServiceException("FILE_ALREADY_EXISTS", "Failed to copy [".$item->id()."] to [".$to->id()."], target already exists (".$target.")");
 			
 			$result = FALSE;
 			if ($item->isFile()) {
-				$result = copy($this->localPath($item), $target);
+				$result = copy($item->internalPath(), $target);
 			} else {
-				$result = $this->copyFolderRecursively($this->localPath($item), $target);
+				$result = $this->copyFolderRecursively($item->internalPath(), $target);
 			}
 			if (!$result) throw new ServiceException("REQUEST_FAILED", "Failed to copy [".$item->id()." to .".$to->id()."]");
 			
-			return $this->itemWithPath($this->publicPath($target));
+			return $to;
 		}
 		
 		private function copyFolderRecursively($from, $to) { 
@@ -207,12 +231,12 @@
 		} 
 		
 		public function move($item, $to) {			
-			$target = self::joinPath($this->localPath($to), $item->name());
+			$target = self::joinPath($to->internalPath(), $this->filesystemInfo->env()->convertCharset($item->name(), FALSE));
 			if (!$item->isFile()) $target = self::folderPath($target);
-			if (file_exists($target)) throw new ServiceException("FILE_ALREADY_EXISTS", "Failed to move [".$item->id()."] to [".$to->id()."], target already exists");
-			if (!rename($this->localPath($item), $target)) throw new ServiceException("REQUEST_FAILED", "Failed to move [".$item->id()."]");
+			if (file_exists($target)) throw new ServiceException("FILE_ALREADY_EXISTS", "Failed to move [".$item->id()."] to [".$to->id()."], target already exists (".$target.")");
+			if (!rename($item->internalPath(), $target)) throw new ServiceException("REQUEST_FAILED", "Failed to move [".$item->id()."] to ".$target);
 			
-			return $this->itemWithPath($this->publicPath($target));
+			return $to->filesystem()->createItemWithInternalPath($item->id(), $this->filesystemInfo->env()->convertCharset($target));
 		}
 		
 		public function delete($item) {
@@ -253,28 +277,42 @@
 		}
 		
 		public function createFolder($folder, $name) {
-			$path = self::folderPath(self::joinPath($this->localPath($folder), $name));
+			self::assertFilename($name);
+			
+			$path = self::folderPath(self::joinPath($this->localPath($folder), $this->filesystemInfo->env()->convertCharset($name, FALSE)));
 			if (file_exists($path)) throw new ServiceException("DIR_ALREADY_EXISTS", $folder->id()."/".$name);
-			if (!mkdir($path, $this->filesystemInfo->setting("new_folder_permission_mask"))) throw new ServiceException("CANNOT_CREATE_FOLDER", $folder->id()."/".$name);
-			return $this->itemWithPath($this->publicPath($path));
+			if (!mkdir($path, $this->filesystemInfo->setting("new_folder_permission_mask", TRUE))) {
+				throw new ServiceException("CANNOT_CREATE_FOLDER", $folder->id()."/".$name);
+			} else {
+				chmod($path, $this->filesystemInfo->setting("new_folder_permission_mask", TRUE));
+			}
+			return $this->itemWithPath($this->publicPath($this->filesystemInfo->env()->convertCharset($path)));
 		}
 		
 		public function createFile($folder, $name) {
-			return $this->itemWithPath($this->publicPath(self::joinPath($this->localPath($folder), $name)), TRUE);
+			self::assertFilename($name);
+			
+			$target = self::joinPath($this->localPath($folder), $this->filesystemInfo->env()->convertCharset($name, FALSE));
+			if (file_exists($target)) throw new ServiceException("FILE_ALREADY_EXISTS");
+			return $this->itemWithPath($this->publicPath($this->filesystemInfo->env()->convertCharset($target)));
 		}
 
-		public function fileWithName($folder, $name, $nonExisting = FALSE) {
-			$path = self::joinPath($this->localPath($folder), $name);
-			return $this->itemWithPath($this->publicPath($path), $nonExisting);
+		public function fileWithName($folder, $name) {
+			self::assertFilename($name);
+			
+			$path = self::joinPath($this->localPath($folder), $this->filesystemInfo->env()->convertCharset($name, FALSE));
+			return $this->itemWithPath($this->publicPath($this->filesystemInfo->env()->convertCharset($path)));
 		}
 
-		public function folderWithName($folder, $name, $nonExisting = FALSE) {
-			$path = self::joinPath($this->localPath($folder), $name.DIRECTORY_SEPARATOR);
-			return $this->itemWithPath($this->publicPath($path), $nonExisting);
+		public function folderWithName($folder, $name) {
+			self::assertFilename($name);
+			
+			$path = self::joinPath($this->localPath($folder), $this->filesystemInfo->env()->convertCharset($name, FALSE).DIRECTORY_SEPARATOR);
+			return $this->itemWithPath($this->publicPath($this->filesystemInfo->env()->convertCharset($path)));
 		}
 		
 		public function size($file) {
-			return filesize($this->localPath($file));
+			return sprintf("%u", filesize($this->localPath($file)));
 		}
 		
 		public function lastModified($item) {
@@ -288,39 +326,55 @@
 			return $handle;
 		}
 		
-		public function write($item) {
+		public function write($item, $s) {
 			$handle = @fopen($this->localPath($item), "wb");
 			if (!$handle)
 				throw new ServiceException("REQUEST_FAILED", "Could not open file for writing: ".$item->id());
-			return $handle;
+			while (!feof($s)) {
+				set_time_limit(0);
+				fwrite($handle, fread($s, 1024));
+			}
+			fclose($handle);
 		}
 		
 		public function put($item, $content) {
 			file_put_contents($this->localPath($item), $content);
 		}
-		
-		private function hash($filePath, $type = 'crc32b') {
-			return hash_file($type, $filePath, true);
-		}
-		
+
 		public function addToZip($item, $zip) {
 			if ($item->isFile()) {
-				$stream = $item->read();
-				$zip->add($item->name(), $item->size(), $this->hash($this->localPath($item)), $stream);
-				fclose($stream);
+				$zip->add($item->name(), $this->localPath($item), $item->size());
 			} else {
-				$offset = strlen($this->localPath($item)) - strlen($item->name()) - 1;
-				$files = $this->allFilesRecursively($this->localPath($item));	//TODO rights!
-				
-				foreach($files as $file) {
-					$stream = @fopen($file, "rb");
-					$st = stat($file);
-					$zip->add(substr($file, $offset), $st['size'], $this->hash($file), $stream);
-    				fclose($stream);
+				if ($zip->acceptFolders()) {
+					$zip->add($item->name(), $this->localPath($item));
+				} else {
+					$offset = strlen($this->localPath($item)) - strlen($item->name()) - 1;
+					$files = $this->allFilesRecursively($this->localPath($item));	//TODO rights!
+					
+					foreach($files as $file) {
+						$st = stat($file);
+						$zip->add(substr($file, $offset), $file, $st['size']);
+					}
 				}
 			}
 		}
-				
+		
+		public function __toString() {
+			return "LOCAL (".$this->id.") ".$this->name."(".$this->rootPath.")";
+		}
+
+		public static function assertFilename($name) {
+			if (strlen($name) == 0) return;
+			if (strpos($name, "\\") !== FALSE or strpos($name, "/") !== FALSE)
+				throw new ServiceException("INVALID_REQUEST", "Invalid name [".$name."]");
+		}
+
+		public static function assertPath($path) {
+			if (strlen($path) == 0) return;
+			if (strpos($path, "..\\") !== FALSE or strpos($path, "../") !== FALSE)
+				throw new ServiceException("INVALID_REQUEST", "Invalid path [".$path."]");
+		}
+		
 		static function joinPath($item1, $item2) {
 			return self::folderPath($item1).$item2;
 		}
