@@ -12,7 +12,7 @@
 
 	class ConfigurationServices extends ServicesBase {
 		private static $ITEMS = array("users", "usergroups", "usersgroups", "folders");
-		
+				
 		protected function isValidPath($method, $path) {
 			if (count($path) == 0) return FALSE;
 			if (!in_array($path[0], self::$ITEMS)) return FALSE;
@@ -137,7 +137,18 @@
 				$user['permission_mode'] = strtoupper($user['permission_mode']);
 				$this->env->authentication()->assertPermissionValue($user['permission_mode']);
 				
-				$this->env->configuration()->addUser($user['name'], $user['password'], isset($user['email']) ? $user['email'] : NULL, $user['permission_mode']);
+				$auths = $this->env->settings()->setting("authentication_methods");
+				$auth = NULL;
+				//TODO verify auth
+				if (isset($user['auth']) and $user['auth'] != NULL) $auth = strtoupper($user['auth']);
+
+				$expiration = NULL;
+				//TODO validate time
+				if (isset($user['expiration']) and $user['expiration'] != NULL)
+					$expiration = $user['expiration'];
+				
+				$id = $this->env->configuration()->addUser($user['name'], base64_decode($user['password']), isset($user['email']) ? $user['email'] : NULL, $user['permission_mode'], $expiration, $auth);
+				$this->env->events()->onEvent(UserEvent::userAdded($id, $user['name'], $user['email']));
 				$this->response()->success(TRUE);
 				return;
 			}
@@ -172,7 +183,17 @@
 				$user['permission_mode'] = strtoupper($user['permission_mode']);
 				$this->env->authentication()->assertPermissionValue($user['permission_mode']);
 				
-				$this->env->configuration()->updateUser($userId, $user['name'], isset($user['email']) ? $user['email'] : NULL, $user['permission_mode']);
+				$auth = NULL;
+				if (isset($user['auth']))
+					$auth = strtoupper($user['auth']);
+				//TODO verify $auth
+				
+				$expiration = NULL;
+				//TODO validate time
+				if (isset($user['expiration']) and $user['expiration'] != NULL)
+					$expiration = $user['expiration'];
+
+				$this->env->configuration()->updateUser($userId, $user['name'], isset($user['email']) ? $user['email'] : NULL, $user['permission_mode'], $expiration, $auth);
 				$this->response()->success(TRUE);
 				return;
 			}
@@ -188,12 +209,12 @@
 						
 						if ($userId === 'current') {
 							if (!isset($pw['old'])) throw $this->invalidRequestException();
-							$userId = $this->env->authentication()->getUserId();
+							$userId = $this->env->session()->userId();
 							
 							if ($pw['old'] != $this->env->configuration()->getPassword($userId)) throw new ServiceException("UNAUTHORIZED");
 						}
 						
-						$this->response()->success($this->env->configuration()->changePassword($userId, $pw['new']));
+						$this->response()->success($this->env->configuration()->changePassword($userId, base64_decode($pw['new'])));
 						return;
 				}				
 			}
@@ -219,6 +240,7 @@
 			$userId = $this->path[1];
 			if (count($this->path) == 2) {
 				$this->env->configuration()->removeUser($userId);
+				$this->env->events()->onEvent(UserEvent::userRemoved($userId));
 				$this->response()->success(TRUE);
 				return;
 			}
@@ -256,7 +278,8 @@
 				$group = $this->request->data;
 				if (!isset($group['name'])) throw $this->invalidRequestException();
 								
-				$this->env->configuration()->addUserGroup($group['name'], $group['description']);
+				$id = $this->env->configuration()->addUserGroup($group['name'], $group['description']);
+				$this->env->events()->onEvent(UserEvent::groupAdded($id, $group['name']));
 				$this->response()->success(TRUE);
 				return;
 			}
@@ -295,6 +318,7 @@
 
 			$id = $this->path[1];
 			$this->env->configuration()->removeUserGroup($id);
+			$this->env->events()->onEvent(UserEvent::groupRemoved($id));
 			$this->response()->success(TRUE);			
 		}
 
