@@ -10,7 +10,7 @@
 	 * this entire header must remain intact.
 	 */
 
-	class ServicesBase {
+	abstract class ServicesBase {
 		protected $env;
 		protected $request;
 		protected $id;
@@ -23,12 +23,23 @@
 			$this->path = $path;
 			
 			if (!$this->isValidPath($this->request->method(), $this->path)) throw $this->invalidRequestException();
+			$this->init();
 		}
 		
-		public function isAuthenticationRequired() {
+		protected function init() {}
+
+		public function isAuthenticated() {
+			if ($this->isAuthenticationRequired() and !$this->env->authentication()->isAuthenticated()) return FALSE;
+			if ($this->isAuthenticationRequired() and $this->isAdminRequired() and !$this->env->authentication()->isAdmin()) return FALSE;
+			return TRUE;
+		}
+		
+		protected function isAuthenticationRequired() {
 			return $this->env->configuration()->isAuthenticationRequired();
 		}
 		
+		protected function isAdminRequired() { return FALSE; }
+		
 		protected function isValidPath($method, $path) {
 			return FALSE;
 		}
@@ -64,13 +75,8 @@
 		
 		function processDelete() { throw new ServiceException("INVALID_REQUEST", "Unimplemented method 'delete'"); }
 		
-		protected function item($id, $convert = TRUE) {
-			$i = $convert ? $this->convertItemId($id) : $id;
-			return $this->env->filesystem()->item(base64_decode($i));
-		}
-		
-		protected function convertItemId($id) {
-			return strtr(urldecode($id), '-_,', '+/=');
+		protected function item($id) {
+			return $this->env->filesystem()->item($id);
 		}
 		
 		protected function invalidRequestException($details = NULL) {
@@ -79,7 +85,6 @@
 		
 		function log() {
 			if (!Logging::isDebug()) return;
-			$this->request->log();
 			Logging::logDebug("SERVICE (".get_class($this)."): is_auth_required=".$this->isAuthenticationRequired($this->request));
 		}
 	}
