@@ -11,7 +11,7 @@
 	 */
 
 	class SessionServices extends ServicesBase {
-		private static $PROTOCOL_VERSION = "1_5_0";
+		private static $PROTOCOL_VERSION = "3";
 		private static $GET_ITEMS = array("info", "logout");
 		private static $POST_ITEMS = array("authenticate", "logout");
 		
@@ -25,24 +25,26 @@
 			return TRUE;
 		}
 		
-		public function isAuthenticationRequired() {
+		protected function isAuthenticationRequired() {
 			return FALSE;
 		}
 
 		public function processGet() {
 			if ($this->path[0] === 'logout') {
 				$this->env->events()->onEvent(SessionEvent::logout($this->env->request()->ip()));
-				$this->env->session()->reset();
+				$this->env->session()->end();
 				$this->response()->success(TRUE);
 				return;
 			}
+			$this->env->authentication()->check();
 			$this->response()->success($this->getSessionInfo($this->path[1]));
 		}
 
 		public function processPost() {
 			if ($this->path[0] === 'logout') {
+				$this->env->authentication()->logout();
 				$this->env->events()->onEvent(SessionEvent::logout($this->env->request()->ip()));
-				$this->env->session()->reset();
+				$this->env->session()->end();
 				$this->response()->success(TRUE);
 				return;
 			}
@@ -54,9 +56,15 @@
 			if (!$this->request->hasData("username") or !$this->request->hasData("password") or !$this->request->hasData("protocol_version"))
 				throw new ServiceException("INVALID_REQUEST", "Missing parameters");
 			
-			$this->env->authentication()->authenticate($this->request->data("username"), $this->request->data("password"));
+			$pw = base64_decode($this->request->data("password"));
+			$this->env->authentication()->authenticate($this->request->data("username"), $pw);
 			$this->env->events()->onEvent(SessionEvent::login($this->env->request()->ip()));
-			$this->response()->success($this->getSessionInfo($this->request->data("protocol_version")));
+			
+			$sessionInfo = $this->getSessionInfo($this->request->data("protocol_version"));
+			if ($this->request->hasData("remember") and strcmp($this->request->data("remember"), "1") === 0)
+				$this->env->authentication()->storeCookie();
+
+			$this->response()->success($sessionInfo);
 		}
 		
 		private function getSessionInfo($protocolVersion) {
@@ -67,22 +75,27 @@
 			$this->env->configuration()->checkProtocolVersion($protocolVersion);
 			
 			$auth = $this->env->authentication();
-			$info = array("authentication_required" => $auth->isAuthenticationRequired(), "authenticated" => $auth->isAuthenticated(), "features" => $this->env->features()->getFeatures());
+			$info = array("authentication_required" => $auth->isAuthenticationRequired(), "authenticated" => $auth->isAuthenticated(), "features" => $this->env->features()->getFeatures(), "plugins" => $this->env->plugins()->getSessionInfo(), "plugin_base_url" => $this->env->getPluginBaseUrl());
 			
 			if (!$auth->isAuthenticationRequired() or $auth->isAuthenticated()) {
+				$info["default_permission"] = $this->env->authentication()->getDefaultPermission();
+				
 				$info = array_merge(
 					$info,
 					$this->env->session()->getSessionInfo(),
-					$this->env->authentication()->getUserInfo(),
-					$this->env->filesystem()->getSessionInfo(),
-					$this->env->plugins()->getSessionInfo()
+					$this->env->filesystem()->getSessionInfo()
 				);
 			}
 			if ($this->env->request()->hasParam("type")) {
 				if (strcasecmp($this->env->request()->param("type"), "admin") === 0 and $this->env->authentication()->isAdmin()) {
 					$info["script_location"] = dirname($_SERVER['SCRIPT_FILENAME']);
+					$info["authentication_methods"] = $this->env->settings()->setting("authentication_methods", TRUE);
 				}
 			}
+			include_once("include/Version.info.php");
+			global $VERSION, $REVISION;
+			$info["version"] = $VERSION;
+			$info["revision"] = $REVISION;
 			return $info;
 		}
 		
