@@ -1,7 +1,7 @@
 <?php
 
 	/**
-	 * Copyright (c) 2008- Samuli Jrvel
+	 * Copyright (c) 2008- Samuli Järvelä
 	 *
 	 * All rights reserved. This program and the accompanying materials
 	 * are made available under the terms of the Eclipse Public License v1.0
@@ -16,10 +16,5 @@
 		public function __construct($env) {
 			parent::__construct($env);
 		}
-		
-		public function getDefaultPermission() {
-			if ($this->env->session()->hasParam('default_permission')) return $this->env->session()->param('default_permission');
-			return parent::getDefaultPermission();
-		}
 	}
 ?>
\ No newline at end of file
