@@ -1,7 +1,7 @@
 <?php
 
 	/**
-	 * Copyright (c) 2008- Samuli Jrvel
+	 * Copyright (c) 2008- Samuli Järvelä
 	 *
 	 * All rights reserved. This program and the accompanying materials
 	 * are made available under the terms of the Eclipse Public License v1.0
@@ -51,28 +51,29 @@
 		}
 		
 		public function execCreateTables() {
-			$this->db->execSqlFile("../include/mysql/sql/create_tables.sql");
+			$this->db->execSqlFile("include/mysql/sql/create_tables.sql");
 		}
 		
 		public function execInsertParams() {
-			$this->db->execSqlFile("../include/mysql/sql/params.sql");
+			$this->db->execSqlFile("include/mysql/sql/params.sql");
 		}
 		
 		public function createAdminUser($name, $pw) {
-			$this->db->query("INSERT INTO ".$this->db->table("user")." (name, password, permission_mode) VALUES ('".$this->db->string($name)."','".$pw."','".Authentication::PERMISSION_VALUE_ADMIN."')", FALSE);
+			$a1pw = md5($name.":mollify:".$pw);	//TODO
+			$this->db->query("INSERT INTO ".$this->db->table("user")." (name, password, a1password, permission_mode, is_group) VALUES ('".$this->db->string($name)."','".md5($pw)."','".$a1pw."','".Authentication::PERMISSION_VALUE_ADMIN."', 0)", FALSE);
 		}
 		
 		public function updateVersionStep($from, $to) {
-			$file = "../include/mysql/sql/".$from."-".$to.".sql";
+			$file = "include/mysql/sql/".$from."-".$to.".sql";
 			$this->db->execSqlFile($file);
 		}
 
 		public function execPluginCreateTables($id) {
-			$this->db->execSqlFile("../plugin/".$id."/mysql/install.sql");
+			$this->db->execSqlFile("plugin/".$id."/mysql/install.sql");
 		}
 		
 		public function updatePluginVersionStep($id, $from, $to) {
-			$file = "../plugin/".$id."/mysql/".$from."-".$to.".sql";
+			$file = "plugin/".$id."/mysql/".$from."-".$to.".sql";
 			$this->db->execSqlFile($file);
 		}
 	}
