@@ -15,17 +15,29 @@
 	class Archiver extends PluginBase {
 		public function setup() {
 			$this->addService("archive", "ArchiverServices");
-			$this->env->filesystem()->registerItemContextPlugin("plugin-archiver", $this);	
+			$this->env->filesystem()->registerItemContextPlugin("plugin-archiver", $this);
+			$this->archiveManager = new ArchiveManager($this->env);
 		}
 		
 		public function getItemContextData($item, $details, $key, $data) {
-			if (!$item->isFile()) return FALSE;
-			
-			$ext = $item->extension();
-			// TODO tar etc
-			if (strcasecmp("zip", $ext) != 0) return FALSE;
-			
-			return array("action_extract" => "archive/".$item->id()."/extract");
+			if ($item->isFile()) {
+				$ext = $item->extension();
+				// TODO tar etc
+
+				if (strcasecmp("zip", $ext) != 0) return FALSE;
+				
+				return array(
+					"action_extract" => "archive/".$item->id()."/extract"
+				);
+			} else {
+				return array(
+					"action_compress" => "archive/".$item->id()."/compress"
+				);
+			}
+		}
+		
+		public function getArchiveManager() {
+			return $this->archiveManager;
 		}
 		
 		public function getClientPlugin() {
