@@ -17,15 +17,11 @@
 			return TRUE;
 		}
 		
-		public function isConfigurationSupported($type) {
-			return $type === ConfigurationProvider::TYPE_DATABASE;
-		}
-
 		public function setup() {
 			$logged = $this->getSetting("logged_events", NULL);
 			if (!$logged or count($logged) == 0) $logged = array("*");
 			
-			$this->addService("events", "EventServices");
+			$this->addService("eventlog", "EventLoggingServices");
 			$this->env->features()->addFeature("event_logging");
 			$e = new EventLogger($this->env);
 			
