@@ -16,11 +16,11 @@
 		private $handler;
 		
 		public function version() {
-			return "1_1";
+			return "1_2";
 		}
 
 		public function versionHistory() {
-			return array("1_0", "1_1");
+			return array("1_0", "1_1", "1_2");
 		}
 		
 		public function setup() {
@@ -32,6 +32,14 @@
 
 			$this->env->filesystem()->registerItemContextPlugin("plugin-share", $this->handler);
 		}
+		
+		public function registerHandler($type, $handler) {
+			$this->handler->registerHandler($type, $handler);
+		}
+
+		public function deleteSharesForItem($itemId) {
+			$this->handler->deleteSharesForItem($itemId);
+		}
 				
 		public function getHandler() {
 			return $this->handler;
