@@ -179,6 +179,15 @@
 	}
 })();
 
+if (!Array.prototype.indexOf) { 
+    Array.prototype.indexOf = function(obj, start) {
+         for (var i = (start || 0), j = this.length; i < j; i++) {
+             if (this[i] === obj) { return i; }
+         }
+         return -1;
+    }
+}
+
 function isArray(o) {
 	return Object.prototype.toString.call(o) === '[object Array]';
 }
@@ -202,6 +211,131 @@ function strpos(haystack, needle, offset) {
     return i === -1 ? false : i;
 }
 
+function ItemCollectionPlugin() {
+	var that = this;
+	
+	this.getPluginInfo = function() { return { id: "plugin-itemcollection" }; }
+	
+	this.initialize = function(env) {
+		that.env = env;
+		that.rootsById = false;
+	}
+	
+	this.add = function(items) {
+		that.env.dialog().showInput({
+			title: that.t("itemCollectionsDialogNewTitle"),
+			message: that.t("itemCollectionsDialogNewMessage"),
+			defaultValue: "",
+			on_input: function(n) { that.onAdd(n, items); },
+			input_validator: function(n) { return true; }
+		});
+	}
+	
+	this.onAdd = function(name, items) {
+		that.env.service().post("itemcollections", {name: name, items: items}, function(result) {
+			that.open();
+		},	function(code, error) {
+			alert(error);
+		});
+	};
+	
+	this.open = function() {
+		if (!that.rootsById) {
+			that.rootsById = {};
+			var roots = that.env.session().info().folders;
+			for (var i=0; i<roots.length;i++) that.rootsById[roots[i].id] = roots[i];
+		}
+		
+		that.env.service().get("itemcollections", function(result) {
+			that.env.dialog().showDialog({
+				title: that.t("itemCollectionsDialogTitle"),
+				html: "<div id='itemcollections-dialog-content' class='loading' />",
+				style: "itemCollectionDialog",
+				on_show: function(d) { that.onShowItemCollectionsDialog(d, result); }
+			});
+		},	function(code, error) {
+			alert(error);
+		});
+	};
+	
+	this.onShowItemCollectionsDialog = function(d, list) {
+		mollify.loadContent("itemcollections-dialog-content", that.url("content.html"), function() {
+			d.setMinimumSizeToCurrent();
+			d.center();
+
+			$("#itemcollections-dialog-content").removeClass("loading");
+			$("#itemcollections-dialog-close").click(function() { d.close(); } );
+			that.updateCollectionList($("#itemcollection-list-items"), list, d);
+		});
+	};
+	
+	this.updateCollectionList = function($e, list, d) {
+		if (!list || list.length == 0) {
+			$e.empty().html('<div class="no-collections-msg">'+that.t("itemCollectionsDialogNoCollections")+'</div>');
+			$("#itemcollection-items > .empty-message").hide();
+			return;
+		}
+		
+		that.selected = false;
+		$("#itemcollection-template").tmpl(list).appendTo($e.empty());
+		mollify.localize($e.attr("id"));
+
+		if (mollify.hasPlugin("plugin_share")) $(".itemcollection-share").show();
+		
+		$(".itemcollection").hover(
+			function() {
+				$(this).addClass("hover");
+			},
+			function() {
+				$(this).removeClass("hover");
+			}
+		).click(function(e) {
+			e.preventDefault();
+			$(".itemcollection").removeClass("selected");
+			$(this).addClass("selected");
+			
+			var ic = $(this).tmplItem().data;
+			that.selected = ic;
+			
+			var opt = {
+				root : function() {
+					return that.rootsById[this.data["root_id"]].name;
+				}
+			};
+			$("#itemcollectionitem-template").tmpl(ic.items, opt).appendTo($("#itemcollection-items").empty());
+		});
+
+		$(".itemcollection-action-share").click(function(e) {
+			e.preventDefault();
+			var ic = $(this).tmplItem().data;
+			d.close();
+			mollify.getPlugin("plugin_share").openShares({id:"ic_"+ic.id, name: ic.name, shareTitle: that.t("itemCollectionTitle")});
+			return false;
+		});
+				
+		$(".itemcollection-action-remove").click(function(e) {
+			var ic = $(this).tmplItem().data;
+			that.removeCollection(ic, function(){ d.close(); });
+		});
+	};
+	
+	this.removeCollection = function(ic, cb) {
+		that.env.service().del("itemcollections/"+ic.id, function(result) {
+			cb();
+		},	function(code, error) {
+			alert(error);
+		});
+	}
+	
+	this.url = function(p) {
+		return that.env.service().getPluginUrl("ItemCollection")+"client/"+p;
+	}
+	
+	this.t = function(s) {
+		return that.env.texts().get(s);
+	}
+};
+
 function CommentPlugin() {
 	var that = this;
 	
@@ -606,7 +740,8 @@ function SharePlugin() {
 
 	this.onShowSharesDialog = function(d, item) {
 		mollify.loadContent("share-dialog-content", that.url("content.html"), function() {
-			$("#share-item-title").html(that.t(item.is_file ? 'shareDialogShareFileTitle' : 'shareDialogShareFolderTitle'));
+			var title = item.shareTitle ? item.shareTitle : that.t(item.is_file ? 'shareDialogShareFileTitle' : 'shareDialogShareFolderTitle');
+			$("#share-item-title").html(title);
 			$("#share-item-name").html(item.name);
 			$("#share-dialog-content").removeClass("loading");
 
